==> liveboxplaytv-1.4.6.tar.gz: liveboxplaytv-1.4.6/liveboxplaytv/channels.py <==
# coding: utf-8


CHANNELS = [
 {'epg_id': None, 'index': '-1', 'name': 'N/A', 'wiki_page': None},
 {'epg_id': '0', 'index': '0', 'name': 'Mosaique', 'wiki_page': None},
 {'epg_id': '192', 'index': '1', 'name': 'TF1', 'wiki_page': 'TF1'},
 {'epg_id': '4', 'index': '2', 'name': 'France 2', 'wiki_page': 'France 2'},
 {'epg_id': '80', 'index': '3', 'name': 'France 3', 'wiki_page': 'France 3'},
 {'epg_id': '34', 'index': '4', 'name': 'Canal+', 'wiki_page': 'Canal+'},
 {'epg_id': '47', 'index': '5', 'name': 'France 5', 'wiki_page': 'France 5'},
 {'epg_id': '118', 'index': '6', 'name': 'M6', 'wiki_page': 'M6'},
 {'epg_id': '111', 'index': '7', 'name': 'Arte', 'wiki_page': 'Arte'},
 {'epg_id': '445', 'index': '8', 'name': 'C8', 'wiki_page': 'C8'},
 {'epg_id': '119', 'index': '9', 'name': 'W9', 'wiki_page': 'W9'},
 {'epg_id': '195', 'index': '10', 'name': 'TMC',
  'wiki_page': 'TMC (chaîne de télévision)'},
 {'epg_id': '446', 'index': '11', 'name': 'NT1', 'wiki_page': 'NT1'},
 {'epg_id': '444', 'index': '12', 'name': 'NRJ 12', 'wiki_page': 'NRJ 12'},
 {'epg_id': '234', 'index': '13', 'name': 'LCP/PS',
  'wiki_page': 'LCP (chaîne de télévision)'},
 {'epg_id': '78', 'index': '14', 'name': 'France 4', 'wiki_page': 'France 4'},
 {'epg_id': '481', 'index': '15', 'name': 'BFM TV', 'wiki_page': 'BFM TV'},
 {'epg_id': '226', 'index': '16', 'name': 'i>Télé', 'wiki_page': 'I-Télé'},
 {'epg_id': '458', 'index': '17', 'name': 'CStar', 'wiki_page': 'CStar'},
 {'epg_id': '482', 'index': '18', 'name': 'Gulli', 'wiki_page': 'Gulli'},
 {'epg_id': '160', 'index': '19', 'name': 'France Ô', 'wiki_page': 'France Ô'},
 {'epg_id': '1404', 'index': '20', 'name': 'HD1', 'wiki_page': 'HD1'},
 {'epg_id': '1401',
  'index': '21',
  'name': "L'Equipe 21",
  'wiki_page': "L'Equipe 21"},
 {'epg_id': '1403', 'index': '22', 'name': '6ter', 'wiki_page': '6ter'},
 {'epg_id': '1402',
  'index': '23',
  'name': 'Numéro 23',
  'wiki_page': 'Numéro 23'},
 {'epg_id': '1400',
  'index': '24',
  'name': 'RMC Découverte',
  'wiki_page': 'RMC Découverte'},
 {'epg_id': '1399',
  'index': '25',
  'name': 'Chérie 25',
  'wiki_page': 'Chérie 25'},
 {'epg_id': '112', 'index': '26', 'name': 'LCI', 'wiki_page': 'LCI'},
 {'epg_id': '191', 'index': '34', 'name': 'Téva', 'wiki_page': 'Téva'},
 {'epg_id': '205',
  'index': '35',
  'name': 'TV5 Monde',
  'wiki_page': 'TV5 Monde'},
 {'epg_id': '145',
  'index': '36',
  'name': 'Paris Première',
  'wiki_page': 'Paris Première'},
 {'epg_id': '115', 'index': '37', 'name': 'RTL9', 'wiki_page': 'RTL9'},
 {'epg_id': '225',
  'index': '38',
  'name': 'TV Breizh',
  'wiki_page': 'TV Breizh',
  'max_img_size': 218},
 {'epg_id': '33',
  'index': '40',
  'name': 'Canal+ Cinéma',
  'wiki_page': 'Canal+ Cinéma'},
 {'epg_id': '35',
  'index': '41',
  'name': 'Canal+ Sport',
  'wiki_page': 'Canal+ Sport'},
 {'epg_id': '657',
  'index': '43',
  'name': 'Canal+ Family',
  'wiki_page': 'Canal+ Family'},
 {'epg_id': '30',
  'index': '44',
  'name': 'Canal+ Décalé',
  'wiki_page': 'Canal+ Décalé'},
 {'epg_id': '730', 'index': '50', 'name': 'OCS max', 'wiki_page': 'OCS max'},
 {'epg_id': '733',
  'index': '51',
  'name': 'OCS City "génération HBO"',
  'wiki_page': 'OCS City "génération HBO"'},
 {'epg_id': '732', 'index': '52', 'name': 'OCS choc', 'wiki_page': 'OCS choc'},
 {'epg_id': '734',
  'index': '53',
  'name': 'OCS géants',
  'wiki_page': 'OCS géants'},
 {'epg_id': '185', 'index': '55', 'name': 'TCM', 'wiki_page': 'TCM Cinéma'},
 {'epg_id': '5', 'index': '74', 'name': 'AB1', 'wiki_page': 'AB1'},
 {'epg_id': '58',
  'index': '86',
  'name': 'Disney Channel',
  'wiki_page': 'Disney Channel (France)'},
 {'epg_id': '76', 'index': '87', 'name': 'Eurosport', 'wiki_page': 'Eurosport'},
 {'epg_id': '439',
  'index': '88',
  'name': 'Eurosport 2',
  'wiki_page': 'Eurosport 2'},
 {'epg_id': '321',
  'index': '88',
  'name': 'Boomerang',
  'wiki_page': 'Boomerang'},
 {'epg_id': '924', 'index': '90', 'name': 'Boing', 'wiki_page': 'Boing France'},
 {'epg_id': '7',
  'index': '116',
  'name': "Toute l'histoire",
  'wiki_page': "Toute l'histoire",
  'max_img_size': 243},
 {'epg_id': '12', 'index': '118', 'name': 'Animaux', 'wiki_page': 'Animaux'},
 {'epg_id': '67', 'index': '120', 'name': 'Escales',
  'wiki_page': 'Escales (chaîne de télévision)'},
 {'epg_id': '88', 'index': '125', 'name': 'Histoire', 'wiki_page': 'Histoire'},
 {'epg_id': '451',
  'index': '126',
  'name': 'Ushuaia TV',
  'wiki_page': 'Ushuaia TV'},
 {'epg_id': '38',
  'index': '127',
  'name': 'Chasse et pêche',
  'wiki_page': 'Chasse et Pêche (chaîne de télévision)',
  'max_img_size': 225},
 {'epg_id': '63', 'index': '128', 'name': 'Encyclo', 'wiki_page': 'Encyclo'},
 {'epg_id': '1000000', 'index': '138', 'name': 'NoLife', 'wiki_page': 'NoLife'},
 {'epg_id': '87', 'index': '143', 'name': 'Game One', 'wiki_page': 'Game One'},
 {'epg_id': '6', 'index': '145', 'name': 'Mangas', 'wiki_page': 'Mangas'},
 {'epg_id': '929', 'index': '146', 'name': 'KZTV', 'wiki_page': 'KZTV'},
 {'epg_id': '325',
  'index': '150',
  'name': 'TRACE Urban',
  'wiki_page': 'TRACE Urban'},
 {'epg_id': '605', 'index': '151', 'name': 'NRJ Hits', 'wiki_page': 'NRJ Hits',
  'max_img_size': 149},
 {'epg_id': '241', 'index': '151', 'name': 'MCM Pop', 'wiki_page': 'MCM Pop'},
 {'epg_id': '453',
  'index': '159',
  'name': 'M6 Music Hits',
  'wiki_page': 'M6 Music Hits'},
 {'epg_id': '343', 'index': '160', 'name': 'MCM Top', 'wiki_page': 'MCM Top'},
 {'epg_id': '753',
  'index': '162',
  'name': 'Trace Tropical',
  'wiki_page': 'Trace Tropical'},
 {'epg_id': '64',
  'index': '173',
  'name': 'Equidia Live',
  'wiki_page': 'Equidia Live'},
 {'epg_id': '1146',
  'index': '174',
  'name': 'Equidia Life',
  'wiki_page': 'Equidia Life'},
 {'epg_id': '1290',
  'index': '176',
  'name': 'beIN SPORT 1',
  'wiki_page': 'beIN SPORT 1'},
 {'epg_id': '525',
  'index': '176',
  'name': 'Al Jazeera English',
  'wiki_page': 'Al Jazeera English'},
 {'epg_id': '1304',
  'index': '177',
  'name': 'beIN SPORT 2',
  'wiki_page': 'beIN SPORT 2'},
 {'epg_id': '15',
  'index': '186',
  'name': 'AB Moteurs',
  'wiki_page': 'AB Moteurs'},
 {'epg_id': '415',
  'index': '191',
  'name': 'Nautical Channel',
  'wiki_page': 'Nautical Channel'},
 {'epg_id': '1355',
  'index': '195',
  'name': 'sport365',
  'wiki_page': 'sport365'},
 {'epg_id': '529',
  'index': '227',
  'name': 'France 24',
  'wiki_page': 'France 24'},
 {'epg_id': '53', 'index': '234', 'name': 'CNN', 'wiki_page': 'CNN International'},
 {'epg_id': '19',
  'index': '237',
  'name': 'BBC World',
  'wiki_page': 'BBC World'}]

==> liveboxplaytv-2.0.0.tar.gz: liveboxplaytv-2.0.0/liveboxplaytv/channels.py <==
# coding: utf-8


CHANNELS = [
 {'epg_id': None, 'index': '-1', 'name': 'N/A', 'wiki_page': None},
 {'epg_id': '0', 'index': '0', 'name': 'Mosaique', 'wiki_page': None},
 {'epg_id': '192', 'index': '1', 'name': 'TF1', 'wiki_page': 'TF1'},
 {'epg_id': '4', 'index': '2', 'name': 'France 2', 'wiki_page': 'France 2'},
 {'epg_id': '80', 'index': '3', 'name': 'France 3', 'wiki_page': 'France 3'},
 {'epg_id': '34', 'index': '4', 'name': 'Canal+', 'wiki_page': 'Canal+'},
 {'epg_id': '47', 'index': '5', 'name': 'France 5', 'wiki_page': 'France 5'},
 {'epg_id': '118', 'index': '6', 'name': 'M6', 'wiki_page': 'M6'},
 {'epg_id': '111', 'index': '7', 'name': 'Arte', 'wiki_page': 'Arte'},
 {'epg_id': '445', 'index': '8', 'name': 'C8',
  'wiki_page': 'C8 (chaîne de télévision)'},
 {'epg_id': '119', 'index': '9', 'name': 'W9', 'wiki_page': 'W9'},
 {'epg_id': '195', 'index': '10', 'name': 'TMC',
  'wiki_page': 'TMC (chaîne de télévision)'},
 {'epg_id': '446', 'index': '11', 'name': 'NT1', 'wiki_page': 'NT1'},
 {'epg_id': '444', 'index': '12', 'name': 'NRJ 12', 'wiki_page': 'NRJ 12'},
 {'epg_id': '234', 'index': '13', 'name': 'LCP/PS',
  'wiki_page': 'LCP (chaîne de télévision)'},
 {'epg_id': '78', 'index': '14', 'name': 'France 4', 'wiki_page': 'France 4'},
 {'epg_id': '481', 'index': '15', 'name': 'BFM TV', 'wiki_page': 'BFM TV'},
 {'epg_id': '226', 'index': '16', 'name': 'i>Télé', 'wiki_page': 'I-Télé'},
 {'epg_id': '458', 'index': '17', 'name': 'CStar', 'wiki_page': 'CStar'},
 {'epg_id': '482', 'index': '18', 'name': 'Gulli', 'wiki_page': 'Gulli'},
 {'epg_id': '160', 'index': '19', 'name': 'France Ô', 'wiki_page': 'France Ô'},
 {'epg_id': '1404', 'index': '20', 'name': 'HD1', 'wiki_page': 'HD1'},
 {'epg_id': '1401',
  'index': '21',
  'name': "L'Equipe 21",
  'wiki_page': "L'Equipe 21"},
 {'epg_id': '1403', 'index': '22', 'name': '6ter', 'wiki_page': '6ter'},
 {'epg_id': '1402',
  'index': '23',
  'name': 'Numéro 23',
  'wiki_page': 'Numéro 23'},
 {'epg_id': '1400',
  'index': '24',
  'name': 'RMC Découverte',
  'wiki_page': 'RMC Découverte'},
 {'epg_id': '1399',
  'index': '25',
  'name': 'Chérie 25',
  'wiki_page': 'Chérie 25'},
 {'epg_id': '112', 'index': '26', 'name': 'LCI', 'wiki_page': 'LCI'},
 {'epg_id': '191', 'index': '34', 'name': 'Téva', 'wiki_page': 'Téva'},
 {'epg_id': '205',
  'index': '35',
  'name': 'TV5 Monde',
  'wiki_page': 'TV5 Monde'},
 {'epg_id': '145',
  'index': '36',
  'name': 'Paris Première',
  'wiki_page': 'Paris Première'},
 {'epg_id': '115', 'index': '37', 'name': 'RTL9', 'wiki_page': 'RTL9'},
 {'epg_id': '225',
  'index': '38',
  'name': 'TV Breizh',
  'wiki_page': 'TV Breizh',
  'max_img_size': 218},
 {'epg_id': '33',
  'index': '40',
  'name': 'Canal+ Cinéma',
  'wiki_page': 'Canal+ Cinéma'},
 {'epg_id': '35',
  'index': '41',
  'name': 'Canal+ Sport',
  'wiki_page': 'Canal+ Sport'},
 {'epg_id': '657',
  'index': '43',
  'name': 'Canal+ Family',
  'wiki_page': 'Canal+ Family'},
 {'epg_id': '30',
  'index': '44',
  'name': 'Canal+ Décalé',
  'wiki_page': 'Canal+ Décalé'},
 {'epg_id': '730', 'index': '50', 'name': 'OCS max', 'wiki_page': 'OCS max'},
 {'epg_id': '733',
  'index': '51',
  'name': 'OCS City "génération HBO"',
  'wiki_page': 'OCS City "génération HBO"'},
 {'epg_id': '732', 'index': '52', 'name': 'OCS choc', 'wiki_page': 'OCS choc'},
 {'epg_id': '734',
  'index': '53',
  'name': 'OCS géants',
  'wiki_page': 'OCS géants'},
 {'epg_id': '185', 'index': '55', 'name': 'TCM', 'wiki_page': 'TCM Cinéma'},
 {'epg_id': '5', 'index': '74', 'name': 'AB1', 'wiki_page': 'AB1'},
 {'epg_id': '58',
  'index': '86',
  'name': 'Disney Channel',
  'wiki_page': 'Disney Channel (France)'},
 {'epg_id': '76', 'index': '87', 'name': 'Eurosport', 'wiki_page': 'Eurosport'},
 {'epg_id': '439',
  'index': '88',
  'name': 'Eurosport 2',
  'wiki_page': 'Eurosport 2'},
 {'epg_id': '321',
  'index': '88',
  'name': 'Boomerang',
  'wiki_page': 'Boomerang'},
 {'epg_id': '924', 'index': '90', 'name': 'Boing', 'wiki_page': 'Boing France'},
 {'epg_id': '7',
  'index': '116',
  'name': "Toute l'histoire",
  'wiki_page': "Toute l'histoire",
  'max_img_size': 243},
 {'epg_id': '12', 'index': '118', 'name': 'Animaux', 'wiki_page': 'Animaux'},
 {'epg_id': '67', 'index': '120', 'name': 'Escales',
  'wiki_page': 'Escales (chaîne de télévision)'},
 {'epg_id': '88', 'index': '125', 'name': 'Histoire', 'wiki_page': 'Histoire'},
 {'epg_id': '451',
  'index': '126',
  'name': 'Ushuaia TV',
  'wiki_page': 'Ushuaia TV'},
 {'epg_id': '38',
  'index': '127',
  'name': 'Chasse et pêche',
  'wiki_page': 'Chasse et Pêche (chaîne de télévision)',
  'max_img_size': 225},
 {'epg_id': '63', 'index': '128', 'name': 'Encyclo', 'wiki_page': 'Encyclo'},
 {'epg_id': '1000000', 'index': '138', 'name': 'NoLife', 'wiki_page': 'NoLife'},
 {'epg_id': '87', 'index': '143', 'name': 'Game One', 'wiki_page': 'Game One'},
 {'epg_id': '6', 'index': '145', 'name': 'Mangas', 'wiki_page': 'Mangas'},
 {'epg_id': '929', 'index': '146', 'name': 'KZTV', 'wiki_page': 'KZTV'},
 {'epg_id': '325',
  'index': '150',
  'name': 'TRACE Urban',
  'wiki_page': 'TRACE Urban'},
 {'epg_id': '605', 'index': '151', 'name': 'NRJ Hits', 'wiki_page': 'NRJ Hits',
  'max_img_size': 149},
 {'epg_id': '241', 'index': '151', 'name': 'MCM Pop', 'wiki_page': 'MCM Pop'},
 {'epg_id': '453',
  'index': '159',
  'name': 'M6 Music Hits',
  'wiki_page': 'M6 Music Hits'},
 {'epg_id': '343', 'index': '160', 'name': 'MCM Top', 'wiki_page': 'MCM Top'},
 {'epg_id': '753',
  'index': '162',
  'name': 'Trace Tropical',
  'wiki_page': 'Trace Tropical'},
 {'epg_id': '64',
  'index': '173',
  'name': 'Equidia Live',
  'wiki_page': 'Equidia Live'},
 {'epg_id': '1146',
  'index': '174',
  'name': 'Equidia Life',
  'wiki_page': 'Equidia Life'},
 {'epg_id': '1290',
  'index': '176',
  'name': 'beIN SPORT 1',
  'wiki_page': 'beIN SPORT 1'},
 {'epg_id': '525',
  'index': '176',
  'name': 'Al Jazeera English',
  'wiki_page': 'Al Jazeera English'},
 {'epg_id': '1304',
  'index': '177',
  'name': 'beIN SPORT 2',
  'wiki_page': 'beIN SPORT 2'},
 {'epg_id': '15',
  'index': '186',
  'name': 'AB Moteurs',
  'wiki_page': 'AB Moteurs'},
 {'epg_id': '415',
  'index': '191',
  'name': 'Nautical Channel',
  'wiki_page': 'Nautical Channel'},
 {'epg_id': '1355',
  'index': '195',
  'name': 'sport365',
  'wiki_page': 'sport365'},
 {'epg_id': '529',
  'index': '227',
  'name': 'France 24',
  'wiki_page': 'France 24'},
 {'epg_id': '53', 'index': '234', 'name': 'CNN', 'wiki_page': 'CNN International'},
 {'epg_id': '19',
  'index': '237',
  'name': 'BBC World',
  'wiki_page': 'BBC World'}]
